cvxopt: Python software for convex optimization
===============================================

Description
-----------

CVXOPT is a free software package for convex optimization based on the
Python programming language. It can be used with the interactive Python
interpreter, on the command line by executing Python scripts, or
integrated in other software via Python extension modules. Its main
purpose is to make the development of software for convex optimization
applications straightforward by building on Python's extensive standard
library and on the strengths of Python as a high-level programming
language.


Upstream Contact
----------------

-  J. Dahl <dahl.joachim@gmail.com>
-  L. Vandenberghe <vandenbe@ee.ucla.edu>

https://cvxopt.org/

License
-------

GPLv3 or later. Includes parts under GPLv2, GNU Lesser General Public
License, v2.1. See src/LICENSE for more details. (Sage-compatible)
